@@ -13,10 +13,10 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Library General Public License for more details.
  *
- * You should have received a copy of the GNU Library General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this library; if not, write to the Free
+ * Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301 USA
  */
 
 #if !defined(LIBXFCE4UTIL_INSIDE_LIBXFCE4UTIL_H) && !defined(LIBXFCE4UTIL_COMPILATION)
@@ -28,11 +28,11 @@
 
 #include <glib.h>
 
-G_BEGIN_DECLS;
+G_BEGIN_DECLS
 
 #define LIBXFCE4UTIL_MAJOR_VERSION	4
-#define LIBXFCE4UTIL_MINOR_VERSION	6
-#define LIBXFCE4UTIL_MICRO_VERSION	2
+#define LIBXFCE4UTIL_MINOR_VERSION	10
+#define LIBXFCE4UTIL_MICRO_VERSION	0
 
 #define LIBXFCE4UTIL_CHECK_VERSION(major,minor,micro) \
   (LIBXFCE4UTIL_MAJOR_VERSION > (major) \
@@ -55,6 +55,6 @@ extern const guint libxfce4util_micro_version;
 #endif /* __GNUC__ */
 #endif /* !defined(G_GNUC_WARN_UNUSED_RESULT) */
 
-G_END_DECLS;
+G_END_DECLS
 
 #endif	/* !__LIBXFCE4UTIL_CONFIG_H__ */
